pub struct BalancesResponse {Show 16 fields
pub cents: i64,
pub sats: i64,
pub usdtmicros: i64,
pub card_collateral_cents: i64,
pub card_collateral_sats: i64,
pub card_collateral_usdtmicros: i64,
pub card_total_cents: u64,
pub card_total_collateral_cents: u64,
pub card_bill_projection_cents: i64,
pub card_available_cents: u64,
pub card_available_collateral_cents: u64,
pub card_cashback_redeemable_sats: i64,
pub card_cashback_redeemed_sats: u64,
pub available_cents: i64,
pub available_sats: i64,
pub available_usdtmicros: i64,
}Fields
cents: i64sats: i64usdtmicros: i64card_collateral_cents: i64card_collateral_sats: i64card_collateral_usdtmicros: i64card_total_cents: u64card_total_collateral_cents: u64card_bill_projection_cents: i64card_available_cents: u64card_available_collateral_cents: u64card_cashback_redeemable_sats: i64card_cashback_redeemed_sats: u64available_cents: i64available_sats: i64available_usdtmicros: i64Trait Implementations
Sourceimpl Clone for BalancesResponse
impl Clone for BalancesResponse
Sourcefn clone(&self) -> BalancesResponse
fn clone(&self) -> BalancesResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BalancesResponse
impl Debug for BalancesResponse
Sourceimpl Default for BalancesResponse
impl Default for BalancesResponse
Sourceimpl Message for BalancesResponse
impl Message for BalancesResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BalancesResponse
impl PartialEq for BalancesResponse
impl Copy for BalancesResponse
impl StructuralPartialEq for BalancesResponse