pub struct DetailedTransaction {Show 13 fields
pub id: String,
pub timestamp: u64,
pub status: i32,
pub warning: Option<String>,
pub message: Option<String>,
pub icon: i32,
pub title: String,
pub credit: Option<Amount>,
pub debit: Option<Amount>,
pub sections: Vec<Section>,
pub reversible_transaction: Option<ReversibleTransaction>,
pub reportable_transaction: Option<ReportableTransaction>,
pub report_status: Option<i32>,
}Fields
id: Stringtimestamp: u64status: i32warning: Option<String>message: Option<String>icon: i32title: Stringcredit: Option<Amount>debit: Option<Amount>sections: Vec<Section>reversible_transaction: Option<ReversibleTransaction>reportable_transaction: Option<ReportableTransaction>report_status: Option<i32>Implementations
Sourceimpl DetailedTransaction
impl DetailedTransaction
Sourcepub fn status(&self) -> Status3
pub fn status(&self) -> Status3
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: Status3)
pub fn set_status(&mut self, value: Status3)
Sets status to the provided enum value.
Sourcepub fn warning(&self) -> &str
pub fn warning(&self) -> &str
Returns the value of warning, or the default value if warning is unset.
Sourcepub fn message(&self) -> &str
pub fn message(&self) -> &str
Returns the value of message, or the default value if message is unset.
Sourcepub fn icon(&self) -> Icon
pub fn icon(&self) -> Icon
Returns the enum value of icon, or the default if the field is set to an invalid enum value.
Sourcepub fn report_status(&self) -> TransactionReportStatus
pub fn report_status(&self) -> TransactionReportStatus
Returns the enum value of report_status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_report_status(&mut self, value: TransactionReportStatus)
pub fn set_report_status(&mut self, value: TransactionReportStatus)
Sets report_status to the provided enum value.