pub struct PixTransaction {Show 20 fields
pub id: String,
pub amount_cents: i64,
pub created_at: u64,
pub description: Option<String>,
pub end_to_end_id: String,
pub flow: i32,
pub method: i32,
pub status: i32,
pub receiver_name: String,
pub receiver_tax_id: String,
pub receiver_bank_code: String,
pub receiver_branch_code: String,
pub receiver_account_number: String,
pub receiver_account_type: i32,
pub sender_name: String,
pub sender_tax_id: String,
pub sender_bank_code: String,
pub sender_branch_code: String,
pub sender_account_number: String,
pub sender_account_type: i32,
}Fields
id: Stringamount_cents: i64created_at: u64description: Option<String>end_to_end_id: Stringflow: i32method: i32status: i32receiver_name: Stringreceiver_tax_id: Stringreceiver_bank_code: Stringreceiver_branch_code: Stringreceiver_account_number: Stringreceiver_account_type: i32sender_name: Stringsender_tax_id: Stringsender_bank_code: Stringsender_branch_code: Stringsender_account_number: Stringsender_account_type: i32Implementations
Sourceimpl PixTransaction
impl PixTransaction
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn flow(&self) -> PixTransactionFlow
pub fn flow(&self) -> PixTransactionFlow
Returns the enum value of flow, or the default if the field is set to an invalid enum value.
Sourcepub fn set_flow(&mut self, value: PixTransactionFlow)
pub fn set_flow(&mut self, value: PixTransactionFlow)
Sets flow to the provided enum value.
Sourcepub fn method(&self) -> PixTransactionMethod
pub fn method(&self) -> PixTransactionMethod
Returns the enum value of method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_method(&mut self, value: PixTransactionMethod)
pub fn set_method(&mut self, value: PixTransactionMethod)
Sets method to the provided enum value.
Sourcepub fn status(&self) -> PixTransactionStatus
pub fn status(&self) -> PixTransactionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: PixTransactionStatus)
pub fn set_status(&mut self, value: PixTransactionStatus)
Sets status to the provided enum value.
Sourcepub fn receiver_account_type(&self) -> PixAccountType
pub fn receiver_account_type(&self) -> PixAccountType
Returns the enum value of receiver_account_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_receiver_account_type(&mut self, value: PixAccountType)
pub fn set_receiver_account_type(&mut self, value: PixAccountType)
Sets receiver_account_type to the provided enum value.
Sourcepub fn sender_account_type(&self) -> PixAccountType
pub fn sender_account_type(&self) -> PixAccountType
Returns the enum value of sender_account_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sender_account_type(&mut self, value: PixAccountType)
pub fn set_sender_account_type(&mut self, value: PixAccountType)
Sets sender_account_type to the provided enum value.